@@ -24,7 +24,7 @@ sentopics_print_extend <- function(extended = FALSE) {
 #' @param extended if `TRUE`, extends the print to include some helpful related
 #'   functions. Automatically displayed once per session.
 #' @param ... not used
-#' 
+#'
 #' @return No return value, called for side effects (printing).
 #'
 #' @export
@@ -101,16 +101,16 @@ print.topWords <- function(x, ...) {
 #'   hierarchy (topics for an LDA model).
 #' @param sort if `TRUE`, sorts the plotted topics in a decreasing frequency.
 #' @param ... not used
-#' 
+#'
 #' @return A `plotly` sunburst chart.
 #'
 #' @export
 #' @seealso [topWords()] [LDAvis()]
-#' @examples 
+#' @examples
 #' lda <- LDA(ECB_press_conferences_tokens)
 #' lda <- grow(lda, 100)
 #' plot(lda, nWords = 5)
-#' 
+#'
 #' # only displays the topic proportions
 #' plot(lda, layers = 1)
 ## TODO: add other methods than probability?
@@ -185,7 +185,7 @@ plot.sentopicmodel <- function(x, nWords = 15, layers = 3, sort = FALSE, ...) {
     data <- data[!grepl("^l1_[0-9]+$", parent)]
     data$parent <- sub("l2_[0-9]+$", "", data$parent)
   }
-  
+
   # reorder data clockwise
   if (sort)
     data <- data[order(value)]
@@ -329,10 +329,10 @@ grow.sentopicmodel <- function(x, iterations = 100, nChains = 1,
                                displayProgress = TRUE, computeLikelihood = TRUE,
                                seed = NULL) {
   start_time <- Sys.time()
-  
+
   ## force deep copy
   x <- data.table::copy(x)
-  
+
   if (nChains == 1) {
     if (!is.null(seed)) set.seed(seed * (x$it + 1))
     ## rebuild c++ model
@@ -343,19 +343,19 @@ grow.sentopicmodel <- function(x, iterations = 100, nChains = 1,
     x[names(tmp)] <- tmp
     reorder_sentopicmodel(x)
   } else if (nChains > 1) {
-    
+
     ## CMD check
     chains <- NULL
-    
+
     base <- core(x)
     core(x) <- NULL
-    
+
     if (!is.null(seed)) seed <- seed * (x$it + 1)
-  
+
     FUN <- function(i) {
       report_time <- Sys.time()
       report_processed <- 0L
-      
+
       ## need to duplicate memory location of x$za. Otherwise, all chains
       ## share the same memory location
       x$za <- data.table::copy(x$za)
@@ -368,7 +368,7 @@ grow.sentopicmodel <- function(x, iterations = 100, nChains = 1,
         for (chunk in c(rep(chunkProgress, iterations %/% chunkProgress),
                         iterations %% chunkProgress)) {
           cpp_model$iterate(chunk, FALSE, computeLikelihood)
-          
+
           report_processed <- report_processed + chunk
           if ((Sys.time() - report_time) > 1) { # not too often
             difftime <- difftime(Sys.time(), start_time)
@@ -385,14 +385,14 @@ grow.sentopicmodel <- function(x, iterations = 100, nChains = 1,
         p(amount = report_processed,
           message = sprintf("Elapsed: %.2f %s", difftime, units(difftime)))
       }
-      
+
       extract_cppModel <- get("extract_cppModel",
                               envir = getNamespace("sentopics"))
       tmp <- extract_cppModel(cpp_model, base)
       x[names(tmp)] <- tmp
       x
     }
-    
+
     expr <- quote({
       if (requireNamespace("future.apply", quietly = TRUE)) {
         if (is.null(seed)) seed <- TRUE
@@ -408,24 +408,24 @@ grow.sentopicmodel <- function(x, iterations = 100, nChains = 1,
           if (!inherits(class(future::plan()), "sequential"))
             message("It seems that a parallel setup is registered, but `future.apply` is not installed. Did you omit installing it? Proceeding sequential computation...")
         }
-        ## TODO: align RNGs? 
+        ## TODO: align RNGs?
         if (!is.null(seed)) set.seed(seed)
         chains <- lapply(1:nChains, FUN)
       }
-      
+
       names(chains) <- paste0("chain", 1:nChains)
       class(chains) <- "multiChains"
       attr(chains, "nChains") <- nChains
       attr(chains, "base") <- base
       attr(chains, "containedClass") <- "sentopicmodel"
     })
-    
+
     if (displayProgress & !requireNamespace("progressr", quietly = TRUE)) {
       message("The `progressr` package is required to track progress of multiple chains.")
       displayProgress <- FALSE
     }
-      
-    if (displayProgress) { 
+
+    if (displayProgress) {
       ## determine how often the progress bar is refreshed (too high refresh rate can negatively affect performance)
       # chunkProgress <- min(max((iterations * nChains) %/% 10, 10), 1000, iterations)
       chunkProgress <- min(100, iterations)
@@ -444,7 +444,7 @@ grow.sentopicmodel <- function(x, iterations = 100, nChains = 1,
       environment(p) <- globalenv()
       eval(expr)
     }
-    
+
     chains
   } else {
     stop("Incorrect number of chains specified.")
@@ -457,36 +457,36 @@ grow.multiChains <- function(x, iterations = 100, nChains = NULL,
                              displayProgress = TRUE, computeLikelihood = TRUE,
                              seed = NULL) {
   start_time <- Sys.time()
-  
+
   ## CMD check
   chains <- NULL
-  
+
   nChains <- attr(x, "nChains")
   base <- attr(x, "base")
   containedClass <- attr(x, "containedClass")
-  
+
   x <- unclass(x) ## unclass to prevent usage of `[[.multiChains`
   x <- lapply(x, as.sentopicmodel) ## return to sentopicmodel objects
-  
+
   ## erase posterior in each chain to limit memory transfers
   for (i in seq_along(x)) {
     x[[i]][["L1post"]] <- x[[i]][["L2post"]] <- x[[i]][["phi"]] <- NULL
   }
-  
+
   if (!is.null(seed)) seed <- seed * (x[[1]]$it + 1)
-  
+
   FUN <- function(x) {
     report_time <- Sys.time()
     report_processed <- 0L
-    
+
     rebuild_cppModel <- get("rebuild_cppModel",
                             envir = getNamespace("sentopics"))
     cpp_model <- rebuild_cppModel(x, base)
-    
+
     for (chunk in c(rep(chunkProgress, iterations %/% chunkProgress),
                     iterations %% chunkProgress)) {
       cpp_model$iterate(chunk, FALSE, computeLikelihood)
-      
+
       report_processed <- report_processed + chunk
       if ((Sys.time() - report_time) > 1) { # not too often
         difftime <- difftime(Sys.time(), start_time)
@@ -501,14 +501,14 @@ grow.multiChains <- function(x, iterations = 100, nChains = NULL,
       p(amount = report_processed,
         message = sprintf("Elapsed: %.2f %s", difftime, units(difftime)))
     }
-    
+
     extract_cppModel <- get("extract_cppModel",
                             envir = getNamespace("sentopics"))
     tmp <- extract_cppModel(cpp_model, base)
     x[names(tmp)] <- tmp
     x
   }
-  
+
   expr <- quote({
     if (requireNamespace("future.apply", quietly = TRUE)) {
       if (is.null(seed)) seed <- TRUE
@@ -524,23 +524,23 @@ grow.multiChains <- function(x, iterations = 100, nChains = NULL,
         if (!inherits(class(future::plan()), "sequential"))
           message("It seems that a parallel setup is registered, but `future.apply` is not installed. Did you omit installing it? Proceeding sequential computation...")
       }
-      ## TODO: align RNGs? 
+      ## TODO: align RNGs?
       if (!is.null(seed)) set.seed(seed)
       chains <- lapply(x, FUN)
     }
-    
+
     class(chains) <- "multiChains"
     attr(chains, "nChains") <- nChains
     attr(chains, "base") <- base
     attr(chains, "containedClass") <- containedClass
   })
-  
+
   if (displayProgress & !requireNamespace("progressr", quietly = TRUE)) {
     message("The `progressr` package is required to track progress of multiple chains.")
     displayProgress <- FALSE
   }
-  
-  if (displayProgress) { 
+
+  if (displayProgress) {
     ## determine how often the progress bar is refreshed (too high refresh rate can negatively affect performance)
     # chunkProgress <- min(max((iterations * nChains) %/% 10, 10), 1000, iterations)
     chunkProgress <- min(100, iterations)
@@ -559,7 +559,7 @@ grow.multiChains <- function(x, iterations = 100, nChains = NULL,
     environment(p) <- globalenv()
     eval(expr)
   }
-  
+
   chains
 }
 
@@ -584,24 +584,24 @@ grow.multiChains <- function(x, iterations = 100, nChains = NULL,
 #' model <- grow(model, 10)
 #' reset(model)
 reset <- function(x) {
-  
+
   ## make copy or assignment are reset by reference
   x$za <- data.table::copy(x$za)
-  
+
   class <- class(x)[1]
   x <- as.sentopicmodel(x)
   x$it <- 0
   x$logLikelihood <- NULL
   x$phi <- x$L2post <- x$L1post <- NULL
-  
+
   base <- core(x) ## need to protect base$cleaned from gc
   cpp_model <- rebuild_cppModel(x, base)
   cpp_model$initAssignments()
   # x <- utils::modifyList(x, extract_cppModel(cpp_model, core(x)))
   tmp <- extract_cppModel(cpp_model, base)
   x[names(tmp)] <- tmp
-  
-  
+
+
   fun <- get(paste0("as.", class))
   fun(reorder_sentopicmodel(x))
 }
@@ -612,24 +612,27 @@ reset <- function(x) {
 
 #' Replacement generic for [data.table::melt()]
 #'
-#' Up to the CRAN release of the 1.14.3 version of **data.table**, the
+#' As of the CRAN release of the 1.14.8 version of **data.table**, the
 #' [data.table::melt()] function is not a generic. This function aims to
 #' temporary provide a generic to this function, so that [melt.sentopicmodel()]
 #' can be effectively dispatched when used. Expect this function to disappear
-#' shortly after the release of **data.table** 1.14.3.
+#' shortly after the release of **data.table** 1.14.9.
 #'
 #' @param data an object to melt
 #' @param ... arguments passed to other methods
-#' 
+#'
 #' @return An unkeyed `data.table` containing the molten data.
-#' 
+#'
 #' @seealso [data.table::melt()], [melt.sentopicmodel()]
 #' @export
 melt <- function(data, ...) {
   UseMethod("melt")
 }
-
-# TODO: re-activate once data.table 1.14.3 is released.
+#' @export
+melt.default <- function(data, ...) {
+  data.table::melt(data, ...)
+}
+# TODO: re-activate once data.table 1.14.9 is released.
 # #' @importFrom data.table melt
 # #' @export
 # data.table::melt
@@ -726,7 +729,7 @@ melt.sentopicmodel <- function(data, ..., include_docvars = FALSE) {
 
   base <- attr(x, "base")
   containedClass <- attr(x, "containedClass")
-  
+
   x <- NextMethod()
   core(x) <- base
 
@@ -781,12 +784,12 @@ melt.sentopicmodel <- function(data, ..., include_docvars = FALSE) {
     if (copy) core(x[[i]]) <- data.table::copy(attr(x, "base"))
     else core(x[[i]]) <- attr(x, "base")
   }
-  
+
   fun <- get(paste0("as.", attr(x, "containedClass")))
   x[] <- lapply(x, function(xi) fun(reorder_sentopicmodel(xi)))
   attr(x, "base") <- NULL
   x
-  
+
   # res <- list()
   # for (i in seq_along(x)) {
   #   res[[i]] <- data.table::copy(x[[i]])
